/*
Copyright (C) 2016 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR

This file is part of SMPPIR-CheckIn.

SMPPIR-CheckIn is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

SMPPIR-CheckIn is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with SMPPIR-CheckIn.  If not, see <https://www.gnu.org/licenses/>.
*/

var chakram = require('chakram'), expect = chakram.expect;
var env = require('../enviroment');
const URL = env.URL;

describe('Account', function() {
  it('should create an admin account', function() {
    let name = env.randomWord(env.randomNumber(1, 25));
    let testObject = {
      'email': `${name}@admin.com`,
      'permission': 'admin',
      'registration': 'NMBR#123456789',
      'username': `${name}`,
      'name': `${name.replace(/\b\w/g, l => l.toUpperCase())}`,
      'password': 'admin',
    };
    return chakram.post(`${URL}end_users`, testObject).then(function(myResponse) {
      expect(myResponse).to.have.status(200);
      expect(myResponse.body.result.permission).to.contain('admin');
    });
  });
  it('should create an user account', function() {
    let name = env.randomWord(env.randomNumber(1, 25));
    let testObject = {
      'email': `${name}@enduser.com`,
      'permission': 'user',
      'registration': 'NMBR#321654987',
      'username': `${name}`,
      'name': `${name.replace(/\b\w/g, l => l.toUpperCase())}`,
      'password': 'end_user',
    };
    return chakram.post(`${URL}end_users`, testObject).then(function(myResponse) {
      expect(myResponse).to.have.status(200);
      expect(myResponse.body.result.permission).to.contain('user');
    });
  });
  it('should login to an admin account', function() {
    let testObject = {
      'email': 'abc@admin.com',
      'password': 'admin',
    };
    return chakram.post(`${URL}end_users/login`, testObject).then(function(myResponse) {
      expect(myResponse).to.have.status(200);
      expect(myResponse.body.result).to.be.a('object');
    });
  });
  it('should login to an user account', function() {
    let testObject = {
      'email': 'user@user.com',
      'password': 'user',
    };
    return chakram.post(`${URL}end_users/login`, testObject).then(function(myResponse) {
      expect(myResponse).to.have.status(200);
      expect(myResponse.body.result).to.be.a('object');
    });
  });
  it('should logout', function() {
    let testObject = {
      'email': 'user@user.com',
      'password': 'user',
    };
    return chakram.post(`${URL}end_users/login`, testObject).then(function(myResponse) {
      return chakram.post(`${URL}end_users/logout?access_token=${myResponse.body.result.id}`).then(function(myResponse2) {
        expect(myResponse2).to.have.status(200);
      });
    });
  });
});
